@@ -1,15 +1,13 @@
 """API clients"""
 
 # flake8: noqa
-from .assets import AssetsService
 from .auth import AuthService
 from .bus import MessageBusService
 from .contxt import ContxtService
 from .contxt_deployments import ContxtDeploymentService
 from .ems import EmsService
 from .events import EventsService
-from .facilities import FacilitiesService
-from .health import HealthService
 from .iot import IotDataService, IotService
 from .ngest import NgestService
+from .nionic import NionicService
 from .sis import SisService
